### Name: bayesGARCH
### Title: Bayesian Estimation of the GARCH(1,1) Model with Student-t
###   Innovations
### Aliases: bayesGARCH
### Keywords: models

### ** Examples

  ## LOAD DATA
  data(dem2gbp)
  y <- dem2gbp[1:750]

  ## RUN THE SAMPLER (2 chains)
  MCMC <- bayesGARCH(y, control = list(n.chain = 2, l.chain = 2000))

  ## MCMC ANALYSIS (using coda)
  plot(MCMC)
  autocorr.diag(MCMC)
  gelman.diag(MCMC)
  1-rejectionRate(MCMC)

  ## FORM THE POSTERIOR SAMPLE
  smpl <- formSmpl(MCMC, l.bi = 500)

  ## POSTERIOR STATISTICS
  summary(smpl)
  smpl <- as.matrix(smpl)
  pairs(smpl)

  ## GARCH(1,1) WITH NORMAL INNOVATIONS
  MCMC <- bayesGARCH(y, lambda = 100, delta = 500,
                     control = list(n.chain = 2, l.chain = 2000))



